@@ -16,6 +16,19 @@
  *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *                                                                         *
+ *   In addition, as a special exception, the copyright holders give       *
+ *   permission to link the code of portions of this program with the      *
+ *   OpenSSL library under certain conditions as described in each         *
+ *   individual source file, and distribute linked combinations            *
+ *   including the two.                                                    *
+ *   You must obey the GNU General Public License in all respects          *
+ *   for all of the code used other than OpenSSL.  If you modify           *
+ *   file(s) with this exception, you may extend this exception to your    *
+ *   version of the file(s), but you are not obligated to do so.  If you   *
+ *   do not wish to do so, delete this exception statement from your       *
+ *   version.  If you delete this exception statement from all source      *
+ *   files in the program, then also delete it here.                       *
  ***************************************************************************/
 
 #ifndef _PDF_PARSER_H_
@@ -384,7 +397,12 @@ class PODOFO_API PdfParser : public PdfTokenizer {
      * \param nMaxObjects set max number of objects
      */
     inline static void SetMaxObjectCount( long nMaxObjects );
+
+    inline pdf_long GetXRefOffset(void);
     
+    bool HasXRefStream();
+
+
  protected:
     /** Searches backwards from the end of the file
      *  and tries to find a token.
@@ -454,7 +472,7 @@ class PODOFO_API PdfParser : public PdfTokenizer {
      *  \param nFirstObject object number of the first object
      *  \param nNumObjects  how many objects should be read from this section
      */
-    void ReadXRefSubsection( long long & nFirstObject, long long & nNumObjects );
+    void ReadXRefSubsection( pdf_int64 & nFirstObject, pdf_int64 & nNumObjects );
 
     /** Reads a xref stream contens object
      *  \param lOffset read the stream from this offset
@@ -676,6 +694,14 @@ void PdfParser::SetMaxObjectCount( long nMaxObjects )
     PdfParser::s_nMaxObjects = nMaxObjects;
 }
 
+// -----------------------------------------------------
+//
+// -----------------------------------------------------
+pdf_long PdfParser::GetXRefOffset()
+{
+    return m_nXRefOffset;
+}
+
 };
 
 #endif // _PDF_PARSER_H_
