@@ -16,12 +16,29 @@
  *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *                                                                         *
+ *   In addition, as a special exception, the copyright holders give       *
+ *   permission to link the code of portions of this program with the      *
+ *   OpenSSL library under certain conditions as described in each         *
+ *   individual source file, and distribute linked combinations            *
+ *   including the two.                                                    *
+ *   You must obey the GNU General Public License in all respects          *
+ *   for all of the code used other than OpenSSL.  If you modify           *
+ *   file(s) with this exception, you may extend this exception to your    *
+ *   version of the file(s), but you are not obligated to do so.  If you   *
+ *   do not wish to do so, delete this exception statement from your       *
+ *   version.  If you delete this exception statement from all source      *
+ *   files in the program, then also delete it here.                       *
  ***************************************************************************/
 
 #ifndef _PDF_VARIANT_H_
 #define _PDF_VARIANT_H_
 
+#if defined(__BORLANDC__) || defined( __TURBOC__)
+#include <math.h>
+#else
 #include <cmath>
+#endif
 
 #include "PdfDefines.h"
 #include "PdfRefCountedBuffer.h"
@@ -1022,7 +1039,7 @@ inline void PdfVariant::AssertMutable() const
 {
     if(m_bImmutable) 
     {
-        throw new PdfError( ePdfError_ChangeOnImmutable );
+        throw PdfError( ePdfError_ChangeOnImmutable );
     }
 }
 
