@@ -10,7 +10,7 @@
 
 #define PODOFO_VERSION_MAJOR 0
 #define PODOFO_VERSION_MINOR 9
-#define PODOFO_VERSION_PATCH 1
+#define PODOFO_VERSION_PATCH 3
 
 /* PoDoFo configuration options */
 #define PODOFO_MULTI_THREAD
@@ -36,8 +36,15 @@
 #define PDF_UINT32_TYPENAME uint32_t
 #define PDF_UINT64_TYPENAME uint64_t
 
+/* Sizes of int64 and long, to pick proper printf format */
+#define SZ_INT64 8
+#define SZ_LONG 4
+
 /* Endianness */
-#define TEST_BIG
+/* #undef TEST_BIG */
+
+/* Features */
+/* #undef PODOFO_NO_FONTMANAGER */
 
 /* Libraries */
 #define PODOFO_HAVE_JPEG_LIB
@@ -46,7 +53,8 @@
 #define PODOFO_HAVE_FONTCONFIG
 /* #undef PODOFO_HAVE_LUA */
 /* #undef PODOFO_HAVE_BOOST */
-/* #undef PODOFO_HAVE_CPPUNIT */
+#define PODOFO_HAVE_CPPUNIT
+#define PODOFO_HAVE_OPENSSL
 #define PODOFO_HAVE_LIBIDN
 
 /* Platform quirks */
